@@ -3,11 +3,14 @@ function(libname, pkgname)
 {
     ## Argh.  We do need RWeka's .onLoad() to be run so that the JVM
     ## gets initialized properly ...
-    loadNamespace("RWeka")
-    
-    rJava::.jmergeClassPath(system.file("jar", "snowball.jar",
-                                        package = pkgname,
-                                        lib.loc = libname))
+    ## loadNamespace("RWeka")
+
+    ## <FIXME>
+    ## Add
+    ##   lib.loc = libname
+    ## when rJava adds the lib.loc argument.
+    rJava::.jpackage(pkgname)
+    ## </FIXME>
 }
 
 SnowballStemmer <-
